@@ -17,6 +17,7 @@ module ClassyPrelude
     , unlessM
       -- ** Mutable references
     , module Control.Concurrent.MVar.Lifted
+    , module Control.Concurrent.Chan.Lifted
     , module Control.Concurrent.STM
     , atomically
     , alwaysSTM
@@ -25,6 +26,14 @@ module ClassyPrelude
     , orElseSTM
     , checkSTM
     , module Data.IORef.Lifted
+      -- ** Primitive (exported since 0.9.4)
+    , PrimMonad
+    , PrimState
+    , primToPrim
+    , primToIO
+    , primToST
+    , module Data.Primitive.MutVar
+    , Prim
       -- ** Debugging
     , trace
     , traceShow
@@ -38,9 +47,17 @@ module ClassyPrelude
     , defaultTimeLocale
       -- ** Generics (since 0.8.1)
     , Generic
+      -- ** Transformers (since 0.9.4)
+    , Identity (..)
+    , MonadReader
+    , ask
+    , ReaderT (..)
+    , Reader
       -- * Poly hierarchy
     , module Data.Foldable
     , module Data.Traversable
+      -- ** Bifunctor (since 0.10.0)
+    , module Data.Bifunctor
       -- * Mono hierarchy
     , module Data.MonoTraversable
     , module Data.Sequences
@@ -60,15 +77,16 @@ module ClassyPrelude
     , map
     , concat
     , concatMap
+    , foldMap
+    , fold
     , length
     , null
     , pack
     , unpack
     , repack
     , toList
-    , Traversable.mapM
     , mapM_
-    , Traversable.forM
+    , sequence_
     , forM_
     , any
     , all
@@ -119,6 +137,8 @@ module ClassyPrelude
       -- ** Exceptions
     , module Control.Exception.Enclosed
     , MonadThrow (throwM)
+    , MonadCatch
+    , MonadMask
       -- ** Force types
       -- | Helper functions for situations where type inferer gets confused.
     , asByteString
@@ -136,25 +156,26 @@ module ClassyPrelude
     , asVector
     , asUVector
     , asSVector
+    , asString
     ) where
 
 import qualified Prelude
 import Control.Exception (assert)
 import Control.Exception.Enclosed
-import Control.Monad (when, unless, void, liftM, ap, forever, join, sequence, sequence_, replicateM_, guard, MonadPlus (..), (=<<), (>=>), (<=<), liftM2, liftM3, liftM4, liftM5)
+import Control.Monad (when, unless, void, liftM, ap, forever, join, replicateM_, guard, MonadPlus (..), (=<<), (>=>), (<=<), liftM2, liftM3, liftM4, liftM5)
 import Control.Concurrent.MVar.Lifted
+import Control.Concurrent.Chan.Lifted
 import Control.Concurrent.STM hiding (atomically, always, alwaysSucceeds, retry, orElse, check)
 import qualified Control.Concurrent.STM as STM
 import Data.IORef.Lifted
 import qualified Data.Monoid as Monoid
-import qualified Data.Traversable as Traversable
-import Data.Traversable (Traversable)
+import Data.Traversable (Traversable (..), for, forM)
 import Data.Foldable (Foldable)
 import Data.IOData (IOData (..))
-import Control.Monad.Catch (MonadThrow (throwM))
+import Control.Monad.Catch (MonadThrow (throwM), MonadCatch, MonadMask)
 
 import Data.Vector.Instances ()
-import CorePrelude hiding (print, undefined, (<>))
+import CorePrelude hiding (print, undefined, (<>), catMaybes, first, second)
 import Data.ChunkedZip
 import qualified Data.Char as Char
 import Data.Sequences
@@ -188,6 +209,14 @@ import Data.Textual.Encoding
 import Data.Sequences.Lazy
 import GHC.Generics (Generic)
 
+import Control.Monad.Primitive (PrimMonad, PrimState, primToPrim, primToIO, primToST)
+import Data.Primitive.MutVar
+import Data.Primitive.Types (Prim)
+
+import Data.Functor.Identity (Identity (..))
+import Control.Monad.Reader (MonadReader, ask, ReaderT (..), Reader)
+import Data.Bifunctor
+
 tshow :: Show a => a -> Text
 tshow = fromList . Prelude.show
 
@@ -262,6 +291,15 @@ forM_ = oforM_
 
 concatMap :: (Monoid m, MonoFoldable c) => (Element c -> m) -> c -> m
 concatMap = ofoldMap
+{-# INLINE concatMap #-}
+
+foldMap :: (Monoid m, MonoFoldable c) => (Element c -> m) -> c -> m
+foldMap = ofoldMap
+{-# INLINE foldMap #-}
+
+fold :: (Monoid (Element c), MonoFoldable c) => c -> Element c
+fold = ofoldMap id
+{-# INLINE fold #-}
 
 foldr :: MonoFoldable c => (Element c -> b -> b) -> b -> c -> b
 foldr = ofoldr
@@ -357,6 +395,9 @@ asUVector = id
 asSVector :: SVector a -> SVector a
 asSVector = id
 
+asString :: [Char] -> [Char]
+asString = id
+
 print :: (Show a, MonadIO m) => a -> m ()
 print = liftIO . Prelude.print
 
@@ -528,3 +569,7 @@ whenM mbool action = mbool >>= flip when action
 -- Since 0.9.2
 unlessM :: Monad m => m Bool -> m () -> m ()
 unlessM mbool action = mbool >>= flip unless action
+
+sequence_ :: (Monad m, MonoFoldable mono, Element mono ~ (m a)) => mono -> m ()
+sequence_ = mapM_ (>> return ())
+{-# INLINE sequence_ #-}
